Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/edwh_files_plugin/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/edwh_files_plugin/compression.py | 217 | 37 | 0 | 58 | 14 | 81%
src/edwh_files_plugin/files_plugin.py | 111 | 111 | 0 | 30 | 0 | 0%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_compression.py | 112 | 0 | 0 | 2 | 0 | 100%
Total | 440 | 148 | 0 | 90 | 14 | 64%

No items found using the specified filter.